====================================================================
Kane's Method, Lagrange's Method & Associated Functions (Docstrings)
====================================================================

Kane
====

.. automodule:: sympy.physics.mechanics.kane
   :members:


partial_velocity
================

This method is the same as :mod:`physics.vector`'s 
:mod:`partial_velocity`.

LagrangesMethod
===============

.. automodule:: sympy.physics.mechanics.lagrange
   :members:
